@@ -7,9 +7,6 @@ package Params::Callbacks;
 # wish, but if you redistribute a modified version, please attach a note
 # listing the modifications you have made.
 
-use strict;
-use warnings;
-
 =pod
 
 =encoding utf-8
@@ -20,6 +17,7 @@ Params::Callbacks - Make your subroutines accept blocking callbacks
 
 =head1 SYNOPSIS
 
+    use Params::Callbacks ':all';
     use Data::Dumper;
     
     $Data::Dumper::Indent = 0;
@@ -58,12 +56,15 @@ into reverse.
   
 =cut
 
+use strict;
+use warnings;
+
 use Exporter ();
-use Scalar::Util qw(reftype blessed);
+use Scalar::Util qw(blessed);
 use Carp qw(confess);
 use namespace::clean;
 
-our $VERSION = '2.000001';
+our $VERSION = '2.001000';
 $VERSION = eval $VERSION;
 
 our @ISA         = qw(Exporter);
